@@ -1,6 +1,8 @@
+
+
 package swat;
 
-our $VERSION = '0.1.76';
+our $VERSION = '0.1.77';
 
 use base 'Exporter'; 
 
@@ -16,11 +18,27 @@ sub version {
 package main;
 
 use strict;
-use Test::More;
-use Data::Dumper;
-use File::Temp qw/ tempfile /;
-use swat::story;
+
 use Carp;
+use File::Temp qw/ tempfile /;
+
+use Test::More;
+use swat::story;
+
+use Carp;
+use Config::Tiny;
+
+my $config;
+
+sub config {
+
+    unless ($config){
+        $config = Config::Tiny->read(
+            get_prop('ini_file_path') || $ENV{'suite_ini_file'} || 'suite.ini'
+            ) or confess "can't read ini file: $!";
+    }
+    return $config;
+}
 
 sub execute_with_retry {
 
@@ -43,12 +61,12 @@ sub make_http_request {
 
     my ($fh, $content_file) = tempfile( DIR => get_prop('test_root_dir') );
 
-    if (get_prop('response')){
+    if (get_prop('response') and @{get_prop('response')} ){
 
-        ok(1,"response is already set");
+        ok(1,'response is already set');
 
         open F, ">", $content_file or die $!;
-        print F get_prop('response');
+        print F ( join "\n", @{get_prop('response')});
         close F;
 
         diag "response saved to $content_file";
@@ -133,7 +151,7 @@ sub header {
     ok(1, "hostname: $hostname");
     ok(1, "resource: $resource");
     ok(1, "http method: $http_method");
-    if ( get_prop('response' )){
+    if ( @{get_prop('response' )}){
         ok(1, 'response is set, so we do not use curl')
     }
     ok(1,"swat module: $swat_module");
@@ -286,7 +304,7 @@ Swat test stories always answers on 2 type of questions:
 
 =item *
 
-I<What kind of> http request should be send.
+I<What kind of> http request should be sent.
 
 
 =item *
@@ -317,7 +335,7 @@ http responses
 
 =back
 
-Swat leverages unix file system to build an I<analogy> for these things:
+Swat leverages Unix file system to build an I<analogy> for these things:
 
 
 =head2 HTTP resources
@@ -340,7 +358,7 @@ I<HTTP method is just a file>. You have to create a file to define a http method
 
 Obviously `http methods' files should be located at `http resource' directories.
 
-The List below describe two http resources ( /foo, /bar/baz ) and tree http methods for these resources ( GET, PUT, DELETE ):
+The list below describes two http resources ( /foo, /bar/baz ) and three http methods for these resources ( GET, PUT, DELETE ):
 
     * GET  /foo
     * PUT  /foo
@@ -374,7 +392,7 @@ for example means you may define a http schema or port here:
 Swat makes request to a given http resources with a given http methods and then validates a response.
 Swat does this with the help so called I<check lists>, check lists are defined at `http methods' files.
 
-Check list is just a list of expressions a response should match. It might be a plain strings or regular expressions:
+Check list is just a list of expressions a response should match. It might be a set of plain strings or regular expressions:
 
     echo 200 OK > foo/get.txt
     echo 'Hello I am foo' >> foo/get.txt
@@ -504,7 +522,7 @@ A few examples:
 
 =item *
 
-plain strings checks
+plain string checks
 
 
 =back
@@ -783,12 +801,6 @@ C<swat_purge_cache> - remove swat cache files at the end of test run; default va
 
 
 
-=item *
-
-C<swat_my> - sets alternative file path for swat.my configuration file; See L<alternative swat ini files locations|#alternative-swat-ini-files-locations> for the explanation of what is swat.my file.
-
-
-
 =back
 
 
@@ -900,12 +912,6 @@ B<$project_root_directory/swat.ini> -  project root directory
 
 
 
-=item *
-
-B<$cwd/swat.my> - custom settings, swat.my should be located at current working directory
-
-
-
 =back
 
 
@@ -918,8 +924,7 @@ This table describes all possible locations for swat ini files. Swat try to find
     | ~/swat.ini                                | 1           |
     | `project_root_directory'/swat.ini         | 2           |
     | `http resource' directory/swat.ini file   | 3           |
-    | current working directory/swat.my file    | 4           |
-    | environment variables                     | 5           |
+    | environment variables                     | 4           |
 
 In case the same variable is defined more than once at swat ini files with different locations, the file loaded last win:
 
@@ -1017,6 +1022,16 @@ This is an example of setting server response inside swat hook:
     THIS IS A FAKE RESPONSE
     HELLO WORLD
 
+You may call `set_response' more then once:
+
+    set_response("HELLO WORLD");
+    set_response("HELLO WORLD2");
+
+A final response will be:
+
+    HELLO WORLD
+    HELLO WORLD2
+
 Another interesting idea about set_response feature is a I<conditional> http requests.
 
 Let say we have `POST /login' request for user authentication, this is a simple swat story for it:
@@ -1210,7 +1225,7 @@ call `run_swat_module(method,resource,variables)' function inside upstream story
 
 =item *
 
-you can call as many downstearm stories as you wish.
+you can call as many downstream stories as you wish.
 
 
 
@@ -1295,18 +1310,61 @@ Of course more proper approaches for state sharing could be used as singeltones
 
 There are some accessors to a common swat variables:
 
-    project_root_dir()
-    test_root_dir()
-    
-    resource()
-    resource_dir()
-    
-    http_method()
-    hostname()
-    
-    ignore_http_err()
+=over
 
-Be aware of that these are readers not setters.
+=item *
+
+projectI<root>dir()
+
+
+
+=item *
+
+testI<root>dir()
+
+
+
+=item *
+
+resource()
+
+
+
+=item *
+
+resource_dir()
+
+
+
+=item *
+
+http_method()
+
+
+
+=item *
+
+hostname()
+
+
+
+=item *
+
+ignoreI<http>err()
+
+
+
+=item *
+
+config() - returns hash of test suite configuration
+
+
+
+=back
+
+See L<test suite ini file|#test-suite-ini-file> section for details.
+
+Be aware of that these functions are readers not setters.
 
 
 =head2 PERL5LIB
@@ -1364,7 +1422,7 @@ check list file passed to ODO
 
 =item *
 
-http request is exected and response passed to ODO
+http request is executed and response passed to ODO
 
 
 =item *
@@ -1465,9 +1523,41 @@ all prove related parameters could be passed via `--prove' option to prove runne
 Here are some examples:
 
     swat --prove -Q # don't show anythings unless test summary
+    
     swat --prove '-q -s' # run prove tests in random and quite mode
 
 
+=head1 Test suite ini file
+
+Test suite ini file is a configuration file where you may pass any additional data could be used in your tests:
+
+    cat suite.ini
+    
+    [main]
+    
+    foo = 1
+    bar = 2
+
+There is no special magic behind this ini file, except this should be L<Config Tiny|https://metacpan.org/pod/Config::Tiny> compliant configuration file.
+
+By default swat runner looks for file named suite.ini placed at current working directory.
+
+You my redefine this by using suiteI<ini>file environment variable:
+
+    suite_ini_file=/path/to/your/ini/file
+
+Or by `--ini' parameter of story runner:
+
+    swat --ini /path/to/your/ini/file
+
+Once suite ini file is read up one may use it in hook.pm files via config()
+
+    # cat hook.pm
+    
+    my $foo = config()->{main}{foo};
+    my $bar = config()->{main}{bar};
+
+
 =head1 Misc settings
 
 =over
@@ -1514,7 +1604,7 @@ B<project_root_dir> - swat project root directory
 
 In case you don't set one, swat assume it equal to current working directory. Examples:
 
-    # setup project root directory explicitely
+    # setup project root directory explicitly
     swat /foo/bar/baz
     
     # project root directory is CWD
@@ -1531,7 +1621,7 @@ B<host> - basic URL of tested application, should be in curl compatible format
 
 In case host parameter is missing , swat tries to read it up from `host' file. Examples:
 
-    # setup host explicitely
+    # setup host explicitly
     swat /foo/bar/baz 127.0.0.1
     
     # host entry gets read from CWD/host file 
@@ -1547,16 +1637,38 @@ List of swat command line options:
 
 =item *
 
-B<--prove|prove-opts> - see L<prove settings|prove-settings>
-
-
-=item *
-
-B<-t|--test> (could me many) - run subset of swat stories
+B<--prove|prove-opts> - sets prove parameters
 
 
 =back
 
+See L<prove settings|prove-settings>
+
+=over
+
+=item *
+
+B<-t|--test>
+
+
+=back
+
+Sets a distinct sub sets of stories to execute, see L<Running subset of stories|#Running-subset-of-stories>
+
+=over
+
+=item *
+
+B<--ini> - test suite ini file path
+
+
+=back
+
+See L<test suite ini file|#test-suite-ini-file> section for details.
+
+
+=head1 Running subset of stories
+
 Use `-t' options to execute a subset of swat stories:
 
     # run `FOO/*' stories
@@ -1569,16 +1681,19 @@ Use `-t' options to execute a subset of swat stories:
 `-t' option should point to a resource(s) path and be relative to the project root directory 
 
 
+
 =item *
 
 `-t' option should not contain extension part - `.txt'
 
 
+
 =item *
 
 it is possible to use more than one `t' options
 
 
+
 =back
 
 For example:
